import { select, 
        arc,
        csv,
        scaleLinear,
        max,
        scaleBand,
        axisLeft,
        axisBottom,
        format,
       scalePoint,
       extent} 
from 'd3';

const width = 1000
const height = 1000
 
const svg = d3.select('.barchart')
                 .attr('height',height)
                 .attr('width',width)

 
const render = (data) => {
  
      const title = "Scatter Plot Cont.";
  
      // choosing x attribute and y attribute from csv
      const x = "acceleration";
      const y = "weight";
  
      const x_label = "Acceleration";
      const y_label = "Weight";
  
  
      const margin = { left:135,right:200, top:150,bottom:90 };
      const innerWidth = width - margin.left - margin.right;
      const innerHeight = width - margin.top - margin.bottom;
  
      const xFormat = x => { return format("0.3s")(x);  } ;
 
   
      const xValue = d => { return d[x] }
      const yValue = d => { return d[y] }
      
      
      const xScale = scaleLinear()
                        .domain(extent(data,xValue))
                        .range([0,innerWidth]).nice();
  
      const yScale = scaleLinear().domain(extent(data,yValue))
                                .range([0,innerHeight]).nice();
  
      
      const xRange = d => {return xScale(d[x])};
      const yRange = d => {return yScale(d[y])};
  
      const yaxis = axisLeft(yScale).tickSize(-innerWidth)
                                    .tickPadding(20); 
  
      const xaxis = axisBottom(xScale)
                                    .tickFormat(xFormat)
                                    .tickSize(-innerHeight)
                                    .tickPadding(25); 
   
  
      const g = svg.append('g')
                     .attr('transform',`translate(${margin.left},${margin.top})`);

  
      const y_view = g.append('g').call(yaxis)
                           .attr('class','y-label')
            
      y_view.selectAll('.domain').remove();
  
      y_view.append('text').text(y_label)
                           .attr('fill','black')
                           .attr('transform','rotate(-90)')
                           .attr('x',`-${innerHeight/2}`)
                           .attr('y',`-90`)
                           .attr('class','axis-label');
      
 
      const x_view = g.append('g').call(xaxis)
                           .attr('transform',`translate(0,${innerHeight})`)
                           .attr('class','x-label');
   
                            
      x_view.selectAll('.domain').remove();
  
      x_view.append('text').text(x_label)
                           .attr('fill','black')
                           .attr('x',`${innerHeight/2}`)
                           .attr('y',75)
                           .attr('class','axis-label');  
  
   
      g.selectAll('circle').data(data).enter().append('circle')
                                            .attr('cx', xRange )
                                            .attr('cy',yRange)
                                            .attr('r', 10);
  
      g.append('text').text(title)
                      .attr('y',-20)
                      .attr('x',innerWidth/4)
                      .attr('class','chart-title');   

      
                                                   
   }
 
csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then( 
   (row) => { 
     
     
     
     row.forEach( d => {  d.mpg = +d.mpg;
                          d.cylinders = +d.cylinders;
                          d.displacement = +d.displacement;
                          d.horsepower = +d.horsepower;
                          d.weight = +d.weight;
                          d.acceleration = +d.acceleration;
                          d.year = +d.year;
                          } ); 
     console.log(row);
     
     render(row);
   }
);
 
 
